#
# spec file for package libnotify
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libnotify
Version:        0.8.3
Release:        2.4
Summary:        Notifications Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://galago-project.org/
Source:         %{name}-%{version}.tar.zst
Source99:       baselibs.conf

BuildRequires:  docbook5-xsl-stylesheets
BuildRequires:  gobject-introspection-devel
BuildRequires:  meson >= 0.58
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(glib-2.0) >= 2.62.0
BuildRequires:  pkgconfig(gtk+-3.0)

%description
D-BUS notifications library.

%package -n libnotify4
Summary:        Notifications Library
Group:          System/Libraries
Recommends:     notification-daemon

%description -n libnotify4
D-BUS notifications library.

%package -n typelib-1_0-Notify-0_7
Summary:        Notifications Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Notify-0_7
D-BUS notifications library.

This package provides the GObject Introspection bindings for libnotify.

%package tools
Summary:        Notifications Library -- Tools
Group:          System/Libraries
Provides:       libnotify = %{version}
Obsoletes:      libnotify < %{version}

%description tools
D-BUS notifications library.

This package contains the notify-send tool to create notifications.

%package devel
Summary:        Notifications Library
Group:          Development/Libraries/X11
Requires:       libnotify4 = %{version}
Requires:       typelib-1_0-Notify-0_7 = %{version}
Provides:       libnotify-doc = %{version}
Obsoletes:      libnotify-doc < %{version}

%description devel
D-BUS notifications library.

%prep
%autosetup -p1

%build
%meson \
	-Dtests=false \
	-Dintrospection=enabled \
	-Dgtk_doc=true \
	-Ddocbook_docs=disabled \
	-Dman=true \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libnotify4

%files -n libnotify4
%license COPYING
%{_libdir}/*.so.*

%files -n typelib-1_0-Notify-0_7
%{_libdir}/girepository-1.0/Notify-0.7.typelib

%files tools
%{_bindir}/notify-send
%{_mandir}/man1/notify-send.1%{?ext_man}

%files devel
%doc AUTHORS NEWS README.md
%doc %{_datadir}/doc/libnotify-0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%{_datadir}/gir-1.0/*.gir

%changelog
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier updating.
* Tue Oct 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.8.3:
  + This release contains a critical stability/minor security
    update which affects Electron applications that utilize Portal
    notifications (eg, through Flatpak). It is highly recommended
    that all users of libnotify 0.8.x update to this release.
  + Please note that this fix has increased the minimum required
    version of glib to 2.62.0.
  + notification:
  - Use g_signal_connect_object
  - Move disconnect to dispose
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.8.2:
  + Set new summary for library.
  + Docs:
  - Port to gi-docgen.
  - Fix URL to Desktop Notification Spec.
  + meson:
  - Replace deprecated meson.source_root() calls.
  - Bump minimum meson version to 0.58.
  + Introspection docs fixes.
- Following upstreams port to gi-docgen, drop gtk-doc and add
  meson, xsltproc and pkgconfig(gi-docgen) BuildRequires. Also pass
  explicit man=true to meson, ensure we are building manpages.
* Fri Jul 22 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 0.8.1:
  + Keep version of bindings at 0.7.
- Changes from version 0.8.0:
  + Use Desktop Portal Notification when running confined (snap and
    flatpak).
  + Now the library acts like a wrapper in such scenario, with some
    limited.
  + capabilities, but this will enforce security and user control
    over the allowed notifications.
  + notify-send: Handles SIGINT gracefully, closing waiting
    notification.
  + Use NotifyClosedReason enum as closed reason return value.
  + Bump dependency on GLib 2.38.
  + Various introspection docs improvements and fixes.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri May 13 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libnotify-rpmlintrc: no longer needed, all rpmlint issues
  are fixed.
* Fri May  6 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 0.7.12:
  + docs/notify-send: Add --transient option to manpage.
  + notify-send: Move server capabilities check to a separate
    function.
  + notify-send: Add debug message about server not supporting
    persistence.
  + notification: Include sender-pid hint by default if not
    provided.
  + Delete unused notifynotification.xml.
  + notification: Bookend calling NotifyActionCallback
    with temporary reference.
* Thu May  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.7.11
  * Fix potential build errors with old glib version we require
  * notify-send: Add support for boolean hints
  * notify-send: Support passing any hint value, by parsing
    variant strings
  * notify-send: Add explicit option to create transient
    notifications
* Sun Apr  5 2020 Michael Gorse <mgorse@suse.com>
- Remove service files.
* Sat Apr  4 2020 mgorse@suse.com
- Update to version 0.7.9:
  + Added man page for notify-send.
  + Dropped autotools.
- Require docbook5-xsl-stylesheets. Needed for manpage generation.
* Fri Apr  5 2019 bjorn.lie@gmail.com
- Update to version 0.7.8:
  + Support meson build system.
  + notify-send: Support full URLs as hint values.
  + Mic. bug fixes.
- Update _service file to new gitlab home.
- Add meson BuildRequires and macros.
- Drop gnome-common BuildRequires and autogen call, no longer
  needed.
* Mon Feb 26 2018 bjorn.lie@gmail.com
- Update to version 0.7.7+20170717.43aac61:
  + Conditionall call g_type_init() after a version check.
  + build: Update the list of headers in srcdir.
  + notify-send: Call setlocale in main function.
- Switch to git-checkout via source service, following this, add
  gtk-doc and gnome-common BuildRequires ans pass autogen.sh to
  bootstrap tarball and pass --enable-gtk-doc to configure.
- Clean up spec, use autosetup and make_build macros.
- Add libnotify-rpmlintrc, silence rpmlint warning about
  shlib-policy-missing-lib.
* Thu Mar 30 2017 jengelh@inai.de
- Rectify RPM groups
* Tue Feb 28 2017 sor.alexei@meowr.ru
- Spec cleanup.
* Fri Oct 14 2016 zaitor@opensuse.org
- Update to version 0.7.7:
  + Introspection fixes.
  + Allow to disable tests at build time.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 0.7.6:
  + Fix annotation for add_action.
  + Clarify documentation for set-timeout.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Jul  9 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  No GPL-2.0+ files found in the package. The Fedora package is also
  licensed under LGPL-2.1+
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.7.5:
  + Build fixes
  + Documentation improvements
  + Spec clarifications
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Notify-0_7 subpackage.
- Add typelib-1_0-Notify-0_7 Requires to devel subpackage.
* Fri Sep 16 2011 jengelh@medozas.de
- Enable libnotify-devel for all baselibs archs
- Remove redundant tags/sections; use %%_smp_mflags
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 0.7.4:
  + Improve documentation of supported image data formats
  + Test notification removal
  + Build system changes
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 0.7.3:
  + Add a way to change the application name for individual
    notifications.
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 0.7.2:
  + Add a way to change the application name
  + Mark image_path as deprecated
  + Allow properties to be set in any order
* Mon Feb  7 2011 fcrozat@novell.com
- Update to version 0.7.1:
  + Don't export private symbols
  + Introspection support and annotations
  + Documentation cleanups and fixes
  + Ref the pixbuf passed to set_image_from_pixbuf
  + Add tests for new capabilities and hints
  + Update spec to mention "persistence" and "action-icons" server
    capability and "action-icons", "transient" and "resident"
    hints.
  + Bump spec version to 1.2
- Add gobject-introspection-devel BuildRequires to build
  introspection.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gnome-common, gtk-doc BuildRequires.
  + Add call to ./autogen.sh.
  + Enforce gtk-doc html generation by passing --enable-gtk-doc to
    configure.
- Change devel package group from System/Libraries to
  Development/Libraries/X11, to fix rpmlint warning.
* Fri Dec 17 2010 vuntz@opensuse.org
- Update to version 0.7.0:
  + Remove the ability to attach notifications to widgets or
    positions
  + Add a test for the persistence server capability
  + Port to use GBus instead of dbus-glib
  + Add a macro to get library version number
  + Remove GTK+ dependency from library
  + Port tests to GTK+ 3
- Remove pkgconfig(dbus-1), pkgconfig(dbus-glib-1),
  pkgconfig(gtk+-2.0) BuildRequires.
- Add explicit pkgconfig(gdk-pixbuf-2.0) BuildRequires.
- Rename libnotify1 to libnotify4, following the soversion change.
* Mon Oct  4 2010 vuntz@opensuse.org
- Update to version 0.6.0:
  + Fix crashes (bgo#623096, lp#570462).
* Thu Jul 22 2010 vuntz@opensuse.org
- Create a tools subpackage, and move the notify-send utility
  there. The main libnotify package is not needed anymore, so make
  the tools subpackage provide/obsolete it.
- Move the notification-daemon Recommends to libnotify1, since it's
  where it really belongs.
- Remove libnotify Requires in libnotify1: it's not needed.
- Remove dbus-1-devel, dbus-1-glib-devel, glib2-devel, gtk2-devel
  Requires in devel package: they will automatically get added with
  pkgconfig() Requires.
* Fri Jul 16 2010 dimstar@opensuse.org
- Update to version 0.5.1:
  + Remove explicit GTK+ 2.x linking, so that libnotify can link
    against both GTK+ 2.x or GTK+ 3.x
- Changes from version 0.5.0:
  + Support for version 1.1 of notification spec
  - bgo#608089: Applications aborted at finalizing when the dbus
    session is being closed.
  - bgo#608082: Arabic text is misplaced in bubbles (RTL)
  - bgo#608086: wrong return value of notify_init()
  - bgo#612720: Does not compile with -DGSEAL_ENABLE
  - bgo#613999: Use g_strcompress in notify-send to parse \n from
    command line
  - bgo#610880: lazily initialize the daemon.
- BuildRequire gtk3-devel instead of gtk2-devel.
* Fri Jun  4 2010 vuntz@opensuse.org
- Make devel package depend on libnotify1, not libnotify.
* Tue Jan  5 2010 jengelh@medozas.de
- Package baselibs.conf
* Sun Apr 26 2009 vuntz@novell.com
- Do not Require notification-daemon, but Recommend it: there's no
  reason to hard-require it.
* Sat Feb 28 2009 vuntz@novell.com
- Remove BuildRequires: gtk-doc, update-desktop-files.
- Remove dbus-1-x11 Requires: it's wrong (we don't require
  dbus-launch in any way: if the session bus is not there, having
  dbus-launch won't help). The requirement should be in another
  package.
- Merge doc package in devel, with adequate Provides/Obsoletes.
* Sat Jan 31 2009 vuntz@novell.com
- Remove la file.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.4.5:
  + Added GObject property accessors for notification IDs
  + Added support for sending the closed reason in the "closed" signal
    handler.
  + Added support for sending the status icon XID to the notification
    daemon. This will allow better position tracking for context
    notifications.
  + Fixed a breakage where we were including gtkversion.h directly.
- Remove backport libnotify-svn3018.patch
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Tue Oct 28 2008 vuntz@novell.com
- Add libnotify-svn3018.patch, which contains a few fixes from
  upstream svn (no release since early 2007). The most important
  change is a change to be able to work nicely with notification
  icons.
- Spec clean up.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Oct  4 2007 maw@suse.de
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun
- Split out a libnotify1 subpackage.
* Tue Mar  6 2007 sbrabec@suse.cz
- Updated to version version 0.4.4:
  * Bug fixes.
  * Fixed memory leaks.
  * notify_uninit is no longer called automatically at exit.
- License update (#236707).
* Tue Feb 20 2007 aj@suse.de
- Remove unneeded requires on popt.
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Fri Dec  8 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Mon Nov 27 2006 sbrabec@suse.cz
- Build correctly in older products.
- Fixed devel dependencies.
* Thu Aug 31 2006 cschneemann@suse.de
- Updated to version 0.4.2
* Mon Aug 14 2006 ro@suse.de
- added dbus-1-glib-devel to BuildRequires
* Thu May 11 2006 rml@suse.de
- Require dbus-x11 too, because that provides dbus-launch, which
  is how we launch the session bus.  And libnotify needs the
  session bus (Novell bug #174865).
- No need to rerun autogen; just run configure
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 dobey@suse.de
- Updated to version 0.3.2
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 0.3.0.
* Tue Aug  2 2005 rodrigo@suse.de
- Updated to 0.2.1.
* Wed Jun 29 2005 sbrabec@suse.cz
- New SuSE package, pre-0.0.1 version from actual svn snapshot.
